@@ -398,7 +398,11 @@ from .facebook import (
     FacebookIE,
     FacebookPluginsVideoIE,
 )
-from .fancode import FancodeVodIE
+from .fancode import (
+    FancodeVodIE,
+    FancodeLiveIE
+)
+
 from .faz import FazIE
 from .fc2 import (
     FC2IE,
@@ -455,7 +459,11 @@ from .frontendmasters import (
     FrontendMastersCourseIE
 )
 from .fujitv import FujiTVFODPlus7IE
-from .funimation import FunimationIE
+from .funimation import (
+    FunimationIE,
+    FunimationPageIE,
+    FunimationShowIE,
+)
 from .funk import FunkIE
 from .fusion import FusionIE
 from .gaia import GaiaIE
@@ -1060,6 +1068,10 @@ from .rcs import (
     RCSEmbedsIE,
     RCSVariousIE,
 )
+from .rcti import (
+    RCTIPlusIE,
+    RCTIPlusSeriesIE,
+)
 from .rds import RDSIE
 from .redbulltv import (
     RedBullTVIE,
